@@ -8,7 +8,7 @@ package XS::Parse::Sublike::Builder;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -162,9 +162,11 @@ static int S_xs_parse_sublike_any(pTHX_ const struct XSParseSublikeHooks *hooks,
   return (*parseany_func)(aTHX_ hooks, op_ptr);
 }
 
-#define boot_xs_parse_sublike() S_boot_xs_parse_sublike(aTHX)
-static void S_boot_xs_parse_sublike(pTHX) {
-  load_module(PERL_LOADMOD_NOIMPORT, newSVpvs("XS::Parse::Sublike"), NULL, NULL);
+#define boot_xs_parse_sublike(ver) S_boot_xs_parse_sublike(aTHX_ ver)
+static void S_boot_xs_parse_sublike(pTHX_ double ver) {
+  SV *versv = ver ? newSVnv(ver) : NULL;
+
+  load_module(PERL_LOADMOD_NOIMPORT, newSVpvs("XS::Parse::Sublike"), versv, NULL);
 
   int abi_version = SvIV(get_sv("XS::Parse::Sublike::ABIVERSION", 0));
   if(abi_version != XSPARSESUBLIKE_ABI_VERSION)
